@@ -1,7 +1,7 @@
 #pragma once
 #include <QLatin1String>
 
-#define KWIN_PLUGIN_VERSION_STRING "6.0.3"
+#define KWIN_PLUGIN_VERSION_STRING "6.1.2"
 
 #define KWIN_BUILD_DECORATIONS 1
 #define KWIN_BUILD_KCMS 1
@@ -10,9 +10,10 @@
 #define KWIN_BUILD_TABBOX 1
 #define KWIN_BUILD_ACTIVITIES 1
 #define KWIN_BUILD_GLOBALSHORTCUTS 1
+#define KWIN_BUILD_X11 1
 constexpr QLatin1String KWIN_CONFIG("kwinrc");
-constexpr QLatin1String KWIN_VERSION_STRING("6.0.3");
-constexpr QLatin1String XCB_VERSION_STRING("1.16.1");
+constexpr QLatin1String KWIN_VERSION_STRING("6.1.2");
+constexpr QLatin1String XCB_VERSION_STRING("1.17.0");
 constexpr QLatin1String KWIN_KILLER_BIN("/usr/lib/kwin_killer_helper");
 #define HAVE_X11_XCB 1
 #define HAVE_X11_XINPUT 1
@@ -27,5 +28,7 @@ constexpr QLatin1String KWIN_KILLER_BIN("/usr/lib/kwin_killer_helper");
 constexpr QLatin1String BREEZE_KDECORATION_PLUGIN_ID("org.kde.breeze");
 #endif
 #define HAVE_XWAYLAND_LISTENFD 1
+#define HAVE_XWAYLAND_ENABLE_EI_PORTAL 1
 #define HAVE_GLX 1
 #define HAVE_DL_LIBRARY 1
+#define HAVE_WL_DISPLAY_SET_DEFAULT_MAX_BUFFER_SIZE 1
